@@ -565,7 +565,7 @@ void ProcessComandLine(int *argc, char ***argv)
 		} else if ((!strcmp((*argv)[i], "-x")) || (!strcmp((*argv)[i], "--xmessage"))) {
 			xmessage = 1;
 		} else {
-			fprintf(stderr, "dispswitch: unrecognised option %s\n",
+			fprintf(stderr, "thotswap: unrecognised option %s\n",
 				(*argv)[i]);
 			Quit(1);
 		}
