@@ -70,6 +70,7 @@ enum { EMPTY, PRIMARY, AUXILLARY };
 static int id;
 static int power = SCI_MAINS;
 static int selectbay = EMPTY;
+static int oldpercent = -1;
 static int alarms;
 static char *config;
 static BatteryState low,critical;
@@ -657,6 +658,15 @@ void Update(void)
 	else
 		percent = -1;
 
+	/* some times percent fails so catch to prevent display flickering */
+
+	if ((percent==-1) && (oldpercent!=-1)) {
+		percent = oldpercent;
+		oldpercent = -1;
+	} else {
+		oldpercent = percent;
+	}
+
 	reg.ebx = SCI_BATTERY_TIME;
 	if (SciGet(&reg)==SCI_SUCCESS)
 		time = (reg.ecx & 0xffff);
